"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const sucrase_babylon_1 = require("../sucrase-babylon");
const augmentTokens_1 = require("./augmentTokens");
const TokenProcessor_1 = require("./TokenProcessor");
const RootTransformer_1 = require("./transformers/RootTransformer");
const formatTokens_1 = require("./util/formatTokens");
const DEFAULT_BABYLON_PLUGINS = ["jsx", "objectRestSpread", "classProperties"];
function getVersion() {
    // eslint-disable-next-line
    return require("../../package.json").version;
}
exports.getVersion = getVersion;
function transform(code, options) {
    const tokens = getSucraseTokens(code, options);
    const tokenProcessor = new TokenProcessor_1.default(code, tokens);
    return new RootTransformer_1.default(tokenProcessor, options.transforms).transform();
}
exports.transform = transform;
/**
 * Return a string representation of the sucrase tokens, mostly useful for
 * diagnostic purposes.
 */
function getFormattedTokens(code, options) {
    const tokens = getSucraseTokens(code, options);
    return formatTokens_1.default(code, tokens);
}
exports.getFormattedTokens = getFormattedTokens;
function getSucraseTokens(code, options) {
    let babylonPlugins = options.babylonPlugins || DEFAULT_BABYLON_PLUGINS;
    if (options.transforms.includes("flow")) {
        babylonPlugins = [...babylonPlugins, "flow"];
    }
    if (options.transforms.includes("typescript")) {
        babylonPlugins = [...babylonPlugins, "typescript"];
    }
    let tokens = sucrase_babylon_1.getTokens(code, {
        tokens: true,
        sourceType: "module",
        plugins: babylonPlugins,
    } /* tslint:disable-line no-any */);
    tokens = tokens.filter((token) => token.type !== "CommentLine" && token.type !== "CommentBlock");
    augmentTokens_1.default(code, tokens);
    return tokens;
}
